@@ -14,7 +14,7 @@
     import mutagen.[format]
     metadata = mutagen.[format].Open(filename)
 
-`metadata` acts like a dictionary of tags in the file. Tags are generally a
+``metadata`` acts like a dictionary of tags in the file. Tags are generally a
 list of string-like values, but may have additional methods available
 depending on tag or format. They may also be entirely different objects
 for certain keys, again depending on format.
@@ -22,9 +22,9 @@ for certain keys, again depending on format.
 
 from mutagen._util import MutagenError
 from mutagen._file import FileType, StreamInfo, File
-from mutagen._tags import Metadata
+from mutagen._tags import Tags, Metadata, PaddingInfo
 
-version = (1, 30)
+version = (1, 36)
 """Version tuple."""
 
 version_string = ".".join(map(str, version))
@@ -38,4 +38,8 @@ StreamInfo
 
 File
 
+Tags
+
 Metadata
+
+PaddingInfo
