@@ -6,22 +6,18 @@
 # published by the Free Software Foundation
 
 import os
-import glob
 import subprocess
 
+import pytest
+
+import mutagen
+import tests
 from tests import TestCase
 
-PEP8_NAME = "pep8"
-
-has_pep8 = True
-try:
-    subprocess.check_output([PEP8_NAME, "--version"], stderr=subprocess.STDOUT)
-except OSError:
-    has_pep8 = False
-
 
+@pytest.mark.quality
 class TPEP8(TestCase):
-    IGNORE = ["E12", "W601", "E402", "E731", "E211"]
+    IGNORE = ["E128", "W601", "E402", "E731", "W503", "E741", "E305"]
 
     def _run(self, path, ignore=None):
         if ignore is None:
@@ -29,7 +25,7 @@ class TPEP8(TestCase):
         ignore += self.IGNORE
 
         p = subprocess.Popen(
-            [PEP8_NAME, "--ignore=" + ",".join(ignore), path],
+            ["pep8", "--ignore=" + ",".join(ignore), path],
             stderr=subprocess.PIPE, stdout=subprocess.PIPE)
 
         class Future(object):
@@ -44,13 +40,13 @@ class TPEP8(TestCase):
 
         return Future(p)
 
-    def _run_package(self, mod, ignore=None):
-        path = mod.__path__[0]
-        files = glob.glob(os.path.join(path, "*.py"))
-        assert files
+    def test_all(self):
+        paths = [mutagen.__path__[0], tests.__path__[0]]
+
         futures = []
-        for file_ in files:
-            futures.append(self._run(file_, ignore))
+        for path in paths:
+            assert os.path.exists(path)
+            futures.append(self._run(path))
 
         errors = []
         for future in futures:
@@ -60,19 +56,3 @@ class TPEP8(TestCase):
 
         if errors:
             raise Exception("\n".join(errors))
-
-    def test_main_package(self):
-        import mutagen
-        self._run_package(mutagen)
-
-    def test_id3_package(self):
-        import mutagen.id3
-        self._run_package(mutagen.id3)
-
-    def test_tests(self):
-        import tests
-        self._run_package(tests)
-
-
-if not has_pep8:
-    del TPEP8
