@@ -1,16 +1,38 @@
 # -*- coding: utf-8 -*-
 
 import os
-import shutil
 
-from tests import TestCase, DATA_DIR
-from mutagen._compat import cBytesIO, text_type
+from tests import TestCase, DATA_DIR, get_temp_copy
+from mutagen._compat import cBytesIO, text_type, xrange
 from mutagen.mp3 import MP3, error as MP3Error, delete, MPEGInfo, EasyMP3, \
-    BitrateMode
-from mutagen._mp3util import XingHeader, XingHeaderError, VBRIHeader, \
+    BitrateMode, iter_sync
+from mutagen.mp3._util import XingHeader, XingHeaderError, VBRIHeader, \
     VBRIHeaderError, LAMEHeader, LAMEError
 from mutagen.id3 import ID3
-from tempfile import mkstemp
+
+
+class TMP3Util(TestCase):
+
+    def test_find_sync(self):
+
+        def get_syncs(fileobj, max_read):
+            start = fileobj.tell()
+            pos = []
+            for i in iter_sync(fileobj, max_read):
+                pos.append(fileobj.tell() - start)
+            return pos
+
+        self.assertEqual(get_syncs(cBytesIO(b"abc"), 100), [])
+        self.assertEqual(get_syncs(cBytesIO(b""), 100), [])
+        self.assertEqual(get_syncs(cBytesIO(b"a\xff\xe0"), 1), [])
+
+        self.assertEqual(get_syncs(cBytesIO(b"a\xff\xc0\xff\xe0"), 100), [3])
+        self.assertEqual(
+            get_syncs(cBytesIO(b"a\xff\xe0\xff\xe0\xff\xe0"), 100), [1, 3, 5])
+
+        for i in xrange(400):
+            fileobj = cBytesIO(b"\x00" * i + b"\xff\xe0")
+            self.assertEqual(get_syncs(fileobj, 100 + i), [i])
 
 
 class TMP3(TestCase):
@@ -22,10 +44,9 @@ class TMP3(TestCase):
     lame_peak = os.path.join(DATA_DIR, 'lame-peak.mp3')
 
     def setUp(self):
-        original = os.path.join(DATA_DIR, "silence-44-s.mp3")
-        fd, self.filename = mkstemp(suffix='.mp3')
-        os.close(fd)
-        shutil.copy(original, self.filename)
+        self.filename = get_temp_copy(
+            os.path.join(DATA_DIR, "silence-44-s.mp3"))
+
         self.mp3 = MP3(self.filename)
         self.mp3_2 = MP3(self.silence_nov2)
         self.mp3_3 = MP3(self.silence_mpeg2)
@@ -76,10 +97,10 @@ class TMP3(TestCase):
         self.failUnlessEqual(self.mp3_2.tags, ID3(self.silence_nov2))
 
     def test_length(self):
-        self.assertAlmostEquals(self.mp3.info.length, 3.77, 2)
-        self.assertAlmostEquals(self.mp3_2.info.length, 3.77, 2)
-        self.assertAlmostEquals(self.mp3_3.info.length, 3.68475, 4)
-        self.assertAlmostEquals(self.mp3_4.info.length, 3.68475, 4)
+        self.assertAlmostEqual(self.mp3.info.length, 3.77, 2)
+        self.assertAlmostEqual(self.mp3_2.info.length, 3.77, 2)
+        self.assertAlmostEqual(self.mp3_3.info.length, 3.68475, 4)
+        self.assertAlmostEqual(self.mp3_4.info.length, 3.68475, 4)
 
     def test_version(self):
         self.failUnlessEqual(self.mp3.info.version, 1)
@@ -103,6 +124,13 @@ class TMP3(TestCase):
         self.failUnlessRaises(
             MP3Error, MP3, os.path.join(DATA_DIR, 'empty.ofr'))
 
+        self.failUnlessRaises(
+            MP3Error, MP3, os.path.join(DATA_DIR, 'emptyfile.mp3'))
+
+    def test_too_short(self):
+        self.failUnlessRaises(
+            MP3Error, MP3, os.path.join(DATA_DIR, 'too-short.mp3'))
+
     def test_sketchy(self):
         self.failIf(self.mp3.info.sketchy)
         self.failIf(self.mp3_2.info.sketchy)
@@ -112,6 +140,7 @@ class TMP3(TestCase):
     def test_sketchy_notmp3(self):
         notmp3 = MP3(os.path.join(DATA_DIR, "silence-44-s.flac"))
         self.failUnless(notmp3.info.sketchy)
+        self.assertTrue(u"sketchy" in notmp3.info.pprint())
 
     def test_pprint(self):
         self.failUnless(self.mp3.pprint())
@@ -196,21 +225,20 @@ class TMPEGInfo(TestCase):
 
     def test_not_real_file(self):
         filename = os.path.join(DATA_DIR, "silence-44-s-v1.mp3")
-        fileobj = cBytesIO(open(filename, "rb").read(20))
-        MPEGInfo(fileobj)
+        with open(filename, "rb") as h:
+            fileobj = cBytesIO(h.read(20))
+        self.failUnlessRaises(MP3Error, MPEGInfo, fileobj)
 
     def test_empty(self):
         fileobj = cBytesIO(b"")
-        self.failUnlessRaises(IOError, MPEGInfo, fileobj)
+        self.failUnlessRaises(MP3Error, MPEGInfo, fileobj)
 
 
 class TEasyMP3(TestCase):
 
     def setUp(self):
-        original = os.path.join(DATA_DIR, "silence-44-s.mp3")
-        fd, self.filename = mkstemp(suffix='.mp3')
-        os.close(fd)
-        shutil.copy(original, self.filename)
+        self.filename = get_temp_copy(
+            os.path.join(DATA_DIR, "silence-44-s.mp3"))
         self.mp3 = EasyMP3(self.filename)
 
     def test_artist(self):
@@ -225,7 +253,8 @@ class TEasyMP3(TestCase):
         # the tags and get the right offset of the first frame
         easy = self.mp3.info
         noneasy = MP3(self.filename).info
-        nonid3 = MPEGInfo(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            nonid3 = MPEGInfo(h)
 
         self.failUnlessEqual(easy.length, noneasy.length)
         self.failUnlessEqual(noneasy.length, nonid3.length)
@@ -234,13 +263,6 @@ class TEasyMP3(TestCase):
         os.unlink(self.filename)
 
 
-class Issue72_TooShortFile(TestCase):
-    def test_load(self):
-        mp3 = MP3(os.path.join(DATA_DIR, 'too-short.mp3'))
-        self.failUnlessEqual(mp3["TIT2"], "Track 10")
-        self.failUnlessAlmostEqual(mp3.info.length, 0.03, 2)
-
-
 class TXingHeader(TestCase):
 
     def test_valid_info_header(self):
