@@ -2,15 +2,13 @@
 
 import os
 import random
-import shutil
 import subprocess
 
 from mutagen._compat import BytesIO, xrange
-from tests import TestCase, DATA_DIR
+from tests import TestCase, DATA_DIR, get_temp_copy
 from mutagen.ogg import OggPage, error as OggError
 from mutagen._util import cdata
 from mutagen import _util
-from tempfile import mkstemp
 
 
 class TOggPage(TestCase):
@@ -237,19 +235,14 @@ class TOggPage(TestCase):
 
     def test_renumber_reread(self):
         try:
-            fd, filename = mkstemp(suffix=".ogg")
-            os.close(fd)
-            shutil.copy(os.path.join(DATA_DIR, "multipagecomment.ogg"),
-                        filename)
+            filename = get_temp_copy(
+                os.path.join(DATA_DIR, "multipagecomment.ogg"))
             with open(filename, "rb+") as fileobj:
                 OggPage.renumber(fileobj, 1002429366, 20)
             with open(filename, "rb+") as fileobj:
                 OggPage.renumber(fileobj, 1002429366, 0)
         finally:
-            try:
-                os.unlink(filename)
-            except OSError:
-                pass
+            os.unlink(filename)
 
     def test_renumber_muxed(self):
         pages = [OggPage() for i in xrange(10)]
@@ -346,13 +339,16 @@ class TOggPage(TestCase):
         except (IOError, OSError):
             print("WARNING: Random data round trip test disabled.")
             return
-        for i in xrange(10):
-            num_packets = random.randrange(2, 100)
-            lengths = [random.randrange(10, 10000)
-                       for i in xrange(num_packets)]
-            packets = list(map(random_file.read, lengths))
-            self.failUnlessEqual(
-                packets, OggPage.to_packets(OggPage.from_packets(packets)))
+        try:
+            for i in xrange(10):
+                num_packets = random.randrange(2, 100)
+                lengths = [random.randrange(10, 10000)
+                           for i in xrange(num_packets)]
+                packets = list(map(random_file.read, lengths))
+                self.failUnlessEqual(
+                    packets, OggPage.to_packets(OggPage.from_packets(packets)))
+        finally:
+            random_file.close()
 
     def test_packet_exactly_255(self):
         page = OggPage()
@@ -610,15 +606,15 @@ class TOggFileTypeMixin(object):
         self.scan_file()
 
     def test_invalid_open(self):
-        self.failUnlessRaises(IOError, self.Kind,
+        self.failUnlessRaises(OggError, self.Kind,
                               os.path.join(DATA_DIR, 'xing.mp3'))
 
     def test_invalid_delete(self):
-        self.failUnlessRaises(IOError, self.audio.delete,
+        self.failUnlessRaises(OggError, self.audio.delete,
                               os.path.join(DATA_DIR, 'xing.mp3'))
 
     def test_invalid_save(self):
-        self.failUnlessRaises(IOError, self.audio.save,
+        self.failUnlessRaises(OggError, self.audio.save,
                               os.path.join(DATA_DIR, 'xing.mp3'))
 
     def ogg_reference(self, filename):
