@@ -5,20 +5,16 @@ import shutil
 
 from mutagen._compat import cBytesIO
 from mutagen.ogg import OggPage
-from mutagen.oggspeex import OggSpeex, OggSpeexInfo, delete
-from tests import TestCase, DATA_DIR
+from mutagen.oggspeex import OggSpeex, OggSpeexInfo, delete, error
+from tests import TestCase, DATA_DIR, get_temp_copy
 from tests.test_ogg import TOggFileTypeMixin
-from tempfile import mkstemp
 
 
 class TOggSpeex(TestCase, TOggFileTypeMixin):
     Kind = OggSpeex
 
     def setUp(self):
-        original = os.path.join(DATA_DIR, "empty.spx")
-        fd, self.filename = mkstemp(suffix='.ogg')
-        os.close(fd)
-        shutil.copy(original, self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, "empty.spx"))
         self.audio = self.Kind(self.filename)
 
     def tearDown(self):
@@ -39,9 +35,10 @@ class TOggSpeex(TestCase, TOggFileTypeMixin):
         self.failUnlessEqual(0, self.audio.info.bitrate)
 
     def test_invalid_not_first(self):
-        page = OggPage(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            page = OggPage(h)
         page.first = False
-        self.failUnlessRaises(IOError, OggSpeexInfo, cBytesIO(page.write()))
+        self.failUnlessRaises(error, OggSpeexInfo, cBytesIO(page.write()))
 
     def test_vendor(self):
         self.failUnless(
@@ -50,9 +47,9 @@ class TOggSpeex(TestCase, TOggFileTypeMixin):
 
     def test_not_my_ogg(self):
         fn = os.path.join(DATA_DIR, 'empty.oggflac')
-        self.failUnlessRaises(IOError, type(self.audio), fn)
-        self.failUnlessRaises(IOError, self.audio.save, fn)
-        self.failUnlessRaises(IOError, self.audio.delete, fn)
+        self.failUnlessRaises(error, type(self.audio), fn)
+        self.failUnlessRaises(error, self.audio.save, fn)
+        self.failUnlessRaises(error, self.audio.delete, fn)
 
     def test_multiplexed_in_headers(self):
         shutil.copy(
